@@ -4,7 +4,7 @@ import argparse
 import numpy as np
 import json
 
-from joule.utils.localnumpypipe import LocalNumpyPipe
+from joule import LocalNumpyPipe
 from nilm.readers import capture
 from nilm.filters import prep, sinefit, reconstructor
 
@@ -42,63 +42,64 @@ def run(meter, duration):
     """
 
     # capture reader
-    capture_args = argparse.Namespace(
-        meter=meter['name'],
-        max_gap=1,
-        disable_alignment=True)
+    capture_args = argparse.Namespace(**{
+        "meter_type": "noncontact",
+        "align": False,
+        "max_gap": 100,  # ignored
+        "nrows": 0,  # run forever
+        "tty": "/dev/nilm/%s-data" % meter["serial_number"]
+    })
 
     my_capture = capture.Capture()
     capture_future = asyncio.ensure_future(
-        my_capture.run(capture_args,
-                       npipe_raw, meter=meter))
+        my_capture.run(capture_args, npipe_raw))
 
     # reconstructor (needed to integrate voltage signal)
-    reconstructor_configs = json.dumps({
-        'noncontact': True,
+    reconstructor_configs = {
         'm_indices': meter['sensors']['current']['sensor_indices'],
         'e_indices': meter['sensors']['voltage']['sensor_index'],
-        'voltage_matrix': [1.0],
-        'current_matrix': np.eye(num_sensors).tolist(),
-        'nominal_frequency': 60,
-        'sampling_frequency': 3000,
         'max_gap': 1,
-        'integrate': meter['sensors']['voltage']['digitally_integrate']
-    })
+        'current_matrix': np.eye(num_sensors).tolist(),
+        'integrate': meter['sensors']['voltage']['digitally_integrate'],
+        'voltage_matrix': [1.0],
+    }
     my_reconstructor = reconstructor.Reconstructor()
     asyncio.ensure_future(
         my_reconstructor.run(
-            argparse.Namespace(config=reconstructor_configs),
+            argparse.Namespace(**reconstructor_configs),
             {'raw': npipe_raw},
             {'iv': npipe_iv}))
 
     # sinefit
-    sinefit_configs = json.dumps({
+    sinefit_configs = {
         'v_index': 1,
-        'min_amp': 10,
-        'min_freq': 55,
         'frequency': 60,
-        'max_freq': 65})
+        'min_freq': 55,
+        'max_freq': 65,
+        'min_amp': 10
+    }
     my_sinefit = sinefit.Sinefit()
     asyncio.ensure_future(
         my_sinefit.run(
-            argparse.Namespace(config=sinefit_configs),
+            argparse.Namespace(**sinefit_configs),
             {'iv': npipe_iv},
             {'zero_crossings': npipe_zc}))
 
     # prep
-    prep_configs = json.dumps({
+    prep_configs = {
         'nshift': 1,
         'nharm': 1,
         'current_indices': list(range(2, num_sensors + 2)),
         'rotations': np.zeros(num_sensors).tolist(),
         'scale_factor': 1.0,
         'merge': True,
-        'polar': False})
+        'polar': False
+    }
 
     my_prep = prep.Prep()
     prep_future = asyncio.ensure_future(
         my_prep.run(
-            argparse.Namespace(config=prep_configs),
+            argparse.Namespace(**prep_configs),
             {'iv': npipe_iv2,
              'zero_crossings': npipe_zc},
             {'prep': npipe_prep}, nrows=nrows))
