@@ -2,7 +2,7 @@
 """
 Configures joule files based off meters.yml
 """
-import logging
+
 import configparser
 import os
 import sys
@@ -84,7 +84,7 @@ class ConfigureCmd(Command):
     def _build_info_stream(self, my_meter, nilmdb_url):
         my_client = Client(nilmdb_url)
         # check if an info stream exists
-        info_path = "/%s/info" % my_meter['name']
+        info_path = "%s/info" % my_meter['path']
         sys.stdout.write("\tbuilding info stream ")
         if(my_client.stream_info(info_path) is None):
             my_client.stream_create(info_path, "uint8_1")
@@ -95,20 +95,33 @@ class ConfigureCmd(Command):
     def _build_module_configs(self, my_meter, legacy):
         sys.stdout.write("\tgenerating module configuration ")
 
-        name = my_meter['name']
-        sensor_path = "/%s/sensor" % name
-        iv_path = "/%s/iv" % name
-        sf_path = "/%s/sinefit" % name
-        prep_path = "/%s/prep" % name
+        path = my_meter['path']
+        sensor_path = "%s/sensor" % path
+        iv_path = "%s/iv" % path
+        sf_path = "%s/sinefit" % path
+        prep_path = "%s/prep" % path
 
         # --meter capture configuration--
         capture_config = configparser.ConfigParser()
-        capture_config['Main'] = {"name": "%s capture" % name,
-                                  "description": "serial data capture",
-                                  "exec_cmd": "nilm-reader-capture %s" % name}
-        capture_config['Source'] = {}
-        capture_config['Destination'] = {"output": sensor_path}
-        path = os.path.join(self.module_dir, "%s_capture.conf" % name)
+        capture_config['Main'] = {"name": "%s capture" % my_meter['name'],
+                                  "exec_cmd": "nilm-reader-capture"}
+        if(my_meter["type"] == 'contact'):
+            capture_config['Main']['description'] = 'ethstream capture from LabJack UE9'
+        else:
+            capture_config['Main']['description'] = 'serial data capture'
+        capture_config['Arguments'] = {
+            "max-gap": 10,
+            "align-with-clock": "yes",
+            "meter-type": my_meter["type"],
+        }
+        if(my_meter["type"] == "contact"):
+            capture_config['Arguments']['ip-address'] = my_meter["ip_address"]
+        else:
+            capture_config['Arguments']['tty'] = my_meter["tty"]
+
+        capture_config['Inputs'] = {}
+        capture_config['Outputs'] = {"output": sensor_path}
+        path = os.path.join(self.module_dir, "%s_capture.conf" % my_meter['name'])
         try:
             with open(path, 'w') as configfile:
                 capture_config.write(configfile)
@@ -116,37 +129,45 @@ class ConfigureCmd(Command):
             self.run_as_root()
         # --meter process configuration--
         process_config = configparser.ConfigParser()
-        if(legacy):
-            # PQ with separate stream for each phase
-            cmd = "nilm-filter-rawtoprep %s" % name
-        else:
-            # PQ with one combined stream
-            cmd = "nilm-filter-rawtoprep %s --merge-prep" % name
-        process_config['Main'] = {"name": "%s process" % name,
+        process_config['Main'] = {"name": "%s process" % my_meter['name'],
                                   "description":
                                   "reconstruct -> sinefit -> prep",
-                                  "exec_cmd": cmd}
-        process_config['Source'] = {"raw": sensor_path}
-        process_config['Destination'] = {"iv": iv_path,
-                                         "zero_crossings": sf_path}
+                                  "exec_cmd": "nilm-filter-rawtoprep"}
+        process_config['Arguments'] = {
+            'meter': my_meter["name"],
+            'frequency': 60,
+            'min-voltage': 10
+        }
+        if(legacy):
+            # PQ with separate stream for each phase
+            process_config['Arguments']['merge'] = "no"
+            process_config['Arguments']['polar'] = "no"
+        else:
+            # PQ with one combined stream
+            process_config['Arguments']['merge'] = "yes"
+            process_config['Arguments']['polar'] = "no"
+
+        process_config['Inputs'] = {"raw": sensor_path}
+        process_config['Outputs'] = {"iv": iv_path,
+                                     "zero_crossings": sf_path}
 
         if(legacy):
             for n in range(my_meter['phases']):
                 ph = 'abc'[n]
                 stream = "%s-%c" % (prep_path, ph)
-                process_config['Destination']['prep-%c' % ph] = stream
+                process_config['Outputs']['prep-%c' % ph] = stream
         else:
-            process_config['Destination']["prep"] = prep_path
+            process_config['Outputs']["prep"] = prep_path
             
-        path = os.path.join(self.module_dir, "%s_process.conf" % name)
+        path = os.path.join(self.module_dir, "%s_process.conf" % my_meter['name'])
         with open(path, 'w') as configfile:
             process_config.write(configfile)
         print("["+COL_GREEN+"OK"+COL_RESET+"]")
 
     def _build_stream_configs(self, my_meter, legacy):
         sys.stdout.write("\tgenerating stream configuration ")
+        path = my_meter['path']
         name = my_meter['name']
-
         # --sensor stream--
         settings = my_meter["streams"]["sensor"]
         if(my_meter["type"] == "noncontact"):
@@ -158,7 +179,7 @@ class ConfigureCmd(Command):
                                  "datatype": dtype,
                                  "keep": settings["keep"],
                                  "decimate": settings["decimate"],
-                                 "path": "/%s/sensor" % name}
+                                 "path": "%s/sensor" % path}
         if(my_meter['type'] == "noncontact"):
             num_channels = 8
         else:  # contact
@@ -166,8 +187,8 @@ class ConfigureCmd(Command):
         for i in range(1, num_channels + 1):
             sensor_config['Element%d' % i] = {"name": "Ch%i" % i,
                                               "units": "ADC"}
-            path = os.path.join(self.stream_dir, "%s_sensor.conf" % name)
-        with open(path, 'w') as configfile:
+            fpath = os.path.join(self.stream_dir, "%s_sensor.conf" % name)
+        with open(fpath, 'w') as configfile:
             sensor_config.write(configfile)
 
         # --iv stream--
@@ -177,7 +198,7 @@ class ConfigureCmd(Command):
                              "datatype": "float32",
                              "keep": settings["keep"],
                              "decimate": settings["decimate"],
-                             "path": "/%s/iv" % name}
+                             "path": "%s/iv" % path}
         i = 1
         if(my_meter["type"] == "noncontact"):
             iv_config['Element1'] = {"name": "Voltage",
@@ -196,8 +217,8 @@ class ConfigureCmd(Command):
             iv_config['Element%d' % i] = {"name": "%c I" % ph_name,
                                           "units": "A"}
             i += 1
-        path = os.path.join(self.stream_dir, "%s_iv.conf" % name)
-        with open(path, 'w') as configfile:
+        fpath = os.path.join(self.stream_dir, "%s_iv.conf" % name)
+        with open(fpath, 'w') as configfile:
             iv_config.write(configfile)
 
         # --sinefit stream--
@@ -207,7 +228,7 @@ class ConfigureCmd(Command):
                              "datatype": "float32",
                              "keep": settings["keep"],
                              "decimate": settings["decimate"],
-                             "path": "/%s/sinefit" % name}
+                             "path": "%s/sinefit" % path}
         sf_config['Element1'] = {"name": "Frequency",
                                  "units": "Hz",
                                  "discrete": "yes"}
@@ -217,8 +238,8 @@ class ConfigureCmd(Command):
         sf_config['Element3'] = {"name": "Offset",
                                  "units": "V",
                                  "discrete": "yes"}
-        path = os.path.join(self.stream_dir, "%s_sinefit.conf" % name)
-        with open(path, 'w') as configfile:
+        fpath = os.path.join(self.stream_dir, "%s_sinefit.conf" % name)
+        with open(fpath, 'w') as configfile:
             sf_config.write(configfile)
 
         # --prep stream--
@@ -231,13 +252,14 @@ class ConfigureCmd(Command):
 
     def _merged_prep_stream(self, my_meter):
         name = my_meter['name']
+        path = my_meter['path']
         settings = my_meter["streams"]["prep"]
         prep_config = configparser.ConfigParser()
         prep_config['Main'] = {"name": "prep",
                                "datatype": "float32",
                                "keep": settings["keep"],
                                "decimate": settings["decimate"],
-                               "path": "/%s/prep" % name}
+                               "path": "%s/prep" % path}
         i = 1
         for ph in range(my_meter["phases"]):
             ph_name = ['A', 'B', 'C'][ph]
@@ -250,12 +272,13 @@ class ConfigureCmd(Command):
                 prep_config['Element%d' % i] = {"name": q_name,
                                                 "units": "W"}
                 i += 1
-        path = os.path.join(self.stream_dir, "%s_prep.conf" % name)
-        with open(path, 'w') as configfile:
+        fpath = os.path.join(self.stream_dir, "%s_prep.conf" % name)
+        with open(fpath, 'w') as configfile:
             prep_config.write(configfile)
 
     def _separate_prep_streams(self, my_meter):
         name = my_meter['name']
+        path = my_meter['path']
         settings = my_meter["streams"]["prep"]
         for n in range(my_meter["phases"]):
             ph = 'abc'[n]
@@ -264,7 +287,7 @@ class ConfigureCmd(Command):
                                    "datatype": "float32",
                                    "keep": settings["keep"],
                                    "decimate": settings["decimate"],
-                                   "path": "/%s/prep-%c" % (name, ph)}
+                                   "path": "%s/prep-%c" % (path, ph)}
             i = 1
             for harm in [1, 3, 5, 7]:
                 prep_config['Element%d' % i] = {"name": "P%d" % harm,
@@ -272,9 +295,9 @@ class ConfigureCmd(Command):
                 prep_config['Element%d' % (i+1)] = {"name": "Q%d" % harm,
                                                     "units": "W"}
                 i += 2
-            path = os.path.join(self.stream_dir,
+            fpath = os.path.join(self.stream_dir,
                                 "%s_prep_%c.conf" % (name, ph))
-            with open(path, 'w') as configfile:
+            with open(fpath, 'w') as configfile:
                 prep_config.write(configfile)
 
     def _remove_modules(self, my_meter):
