@@ -14,11 +14,12 @@ import threading
 import warnings
 
 import matplotlib
+matplotlib.use('tkagg')
 from matplotlib import pyplot as plt
 
 from cliff.command import Command
 
-from joule.utils.localnumpypipe import LocalNumpyPipe
+from joule import LocalNumpyPipe
 from nilm.readers import capture
 from nilm.meter import meter
 from nilm.meter.utils import MeterConfigurationError
@@ -30,7 +31,7 @@ CALIB_DATA_DIR = "/opt/configs/cal_data"
 TYPE_NON_CONTACT = "noncontact"
 
 NON_CONTACT_NUM_POINTS = 300
-CONTACT_NUM_POINTS = 600
+CONTACT_NUM_POINTS = 800
 
 ESC_SEQ = "\x1b["
 COL_RESET = ESC_SEQ + "0m"
@@ -77,7 +78,7 @@ class ScopeCmd(Command):
             exit(1)
 
         ##########
-        # Stop the nilm-capture service if it is running
+        # Stop the jouled service if it is running
         ret = subprocess.call(["pgrep", "jouled"],
                               stdout=FNULL, stderr=FNULL)
         if(ret == 0):
@@ -90,14 +91,23 @@ class ScopeCmd(Command):
             restart_capture = False
 
         # pipes to receive data
-        npipe = LocalNumpyPipe("raw", layout="int16_8")
+        if(my_meter['type'] == 'contact'):
+            npipe = LocalNumpyPipe("raw", layout="uint16_6")
+        else:
+            npipe = LocalNumpyPipe("raw", layout="int16_8")
 
         # capture reader
-        capture_args = argparse.Namespace(
-            meter=my_meter['name'],
-            max_gap=1,
-            disable_alignment=True)
-
+        config = {
+            "meter_type": my_meter['type'],
+            "align": False,
+            "max_gap": 100,  # ignored
+            "nrows": 0  # run forever
+        }
+        if(my_meter["type"] == "noncontact"):
+            config["tty"] = my_meter["tty"]
+        else:
+            config["ip_address"] = my_meter["ip_address"]
+        capture_args = argparse.Namespace(**config)
         my_capture = capture.Capture()
 
         # setup the plot
@@ -105,38 +115,49 @@ class ScopeCmd(Command):
         if(my_meter['type'] == TYPE_NON_CONTACT):
             self.plot_width = NON_CONTACT_NUM_POINTS
 
-        # suppress the rcParam warning 
-        warnings.filterwarnings("ignore",category=UserWarning,module='matplotlib')
+        # suppress the rcParam warning
+        warnings.filterwarnings("ignore",
+                                category=UserWarning,
+                                module='matplotlib')
         (plot, fig, data, ax, bkgd) = self.setup_plot(my_meter, channels)
         fig.canvas.mpl_connect('close_event', self.shutdown)
         # setup the tasks and run the loop
         tasks = [
             asyncio.ensure_future(
-                my_capture.run(capture_args, npipe, meter=my_meter)),
+                my_capture.run(capture_args, npipe)),
             asyncio.ensure_future(self.update_plot(
                 npipe, channels, fig, data, ax, bkgd))]
         loop = asyncio.get_event_loop()
         self.shutdown = False
-        threading.Thread(target=self.run_loop, args=(loop, tasks)).start()
+        t = threading.Thread(target=self.run_loop, args=(loop, tasks))
+        t.start()
         plot.show()
+        
         self.shutdown = True
-        my_capture.stop()
-        time.sleep(1)
-        #force close 
-        loop.close()
-
+        loop.call_soon_threadsafe(my_capture.stop)
+        t.join(timeout=5.0)
+        
     def run_loop(self, loop, tasks):
         asyncio.set_event_loop(loop)
         loop.run_until_complete(asyncio.gather(*tasks))
+        loop.close()
+        print("done with loop")
         
-    def shutdown(self):
-        print("shutting down")
+    def shutdown(self, event):
+        pass
 
     async def update_plot(self, npipe, channels, fig, data, ax, bkgd):
+        dead_loops = 0
+        MAX_DEAD_LOOPS = 10
         while(not self.shutdown):
             sensor_data = await npipe.read(flatten=True)
             if(len(sensor_data) < self.plot_width):
+                await asyncio.sleep(.1)
+                dead_loops += 1
+                if(dead_loops > MAX_DEAD_LOOPS):
+                    break  # the producer is not providing data
                 continue  # not enough data to plot
+            dead_loops = 0
             sensor_data = sensor_data - np.mean(sensor_data, axis=0)
  #           fig.canvas.restore_region(bkgd)
             for i in range(len(channels)):
@@ -148,17 +169,18 @@ class ScopeCmd(Command):
 #                ax.draw_artist(points)
 #            fig.canvas.blit(ax.bbox)
             fig.canvas.draw()
-            consumed_data = len(sensor_data)-len(sensor_data) % self.plot_width
+            consumed_data = len(sensor_data)-(len(sensor_data) % self.plot_width)
             npipe.consume(consumed_data)
             await asyncio.sleep(.1)
-
+        print("exiting plotting coroutine")
+        
     def setup_plot(self, my_meter, channels):
 
         # remove navigation toolbar
         matplotlib.rcParams['toolbar'] = 'None'
 
         fig, ax = plt.subplots(1, 1)
-        ax.hold(True)
+        #ax.hold(True)
         ax.grid(True)
 
         if(my_meter["type"] == TYPE_NON_CONTACT):
@@ -205,6 +227,6 @@ class ScopeCmd(Command):
                 points, = ax.plot(
                     list(range(self.plot_width)), data, label=role)
                 plot_data.append(points)
-        ax.legend()
+        ax.legend(loc=1)  # upper right
         plt.draw()
         return (plt, fig, plot_data, ax, background)
