@@ -9,69 +9,116 @@ from . import helpers
 from joule.client import FilterModule
 
 ARGS_DESC = """
-Pipes
-------------
-Inputs:
-    'iv'             float32 <V, I_A, I_B, ... > 
+---
+:name:
+  NILM Sinefit
+:author:
+  John Donnal, James Paris
+:license:
+  Closed
+:url:
+  http://git.wattsworth.net/wattsworth/nilm.git
+:description:
+  characterize a voltage waveform
+:usage:
+  Compute phase, amplitude and offset at each zero crossing of a signal.
+ 
+  | Arguments     | Default | Description
+  |---------------|---------|---------------------------------
+  |``v-index``    | --  | voltage element (1 indexed)
+  |``frequency``  | 60  | utility line frequency
+  |``min-freq``   | 55  | reject frequencies below threshold
+  |``max-freq``   | 65  | reject frequencies above threshold
+  |``min-amp``    | 10  | reject signals below threshold
 
-Outputs:
-    'zero_crossings' float32 <freq, qmp, phase>
+:inputs:
+ 
+  iv
+  : voltage source (output from nilm-reconstructor)
 
-Arguments
--------------
-config:
-  this should be a JSON encoded dict with the
-  following properties 
+:outputs:
 
-  {
-    'v_index':    N   #voltage data column 1 indexed
-    'frequency':  N.0 #frequency estimate
-     'min_freq':  N.0 #minimum bound
-     'max_freq':  N.0 #max bound
-     'min_amp':   N.0 #min bound (smallest voltage)
-  }
+  zero_crossings
+  : ``float32`` with phase, amplitude and offset elements
+
+:module_config:
+    [Main]
+    name = NILM Sinefit
+    exec_cmd = nilm-filter-sinefit
+
+    [Arguments]
+    v-index = 1
+    frequency = 60
+    min-freq = 55
+    max-freq = 65
+    min-amp = 10
+
+    [Inputs]
+    iv = /path/to/iv
+
+    [Outputs]
+    zero_crossings = /path/to/zero_crossings
+
+:stream_configs:
+  #zero_crossings#
+     [Main]
+     name = Zero Crossings
+     path = /path/to/zero_crossings
+     datatype = float32
+     keep = 1w
+
+     [Element1]
+     name = Amplitude
+     [Element2]
+     name = Offset
+     [Element3]
+     name = Phase
+
+---
 """
 
 
 class Sinefit(FilterModule):
 
-    def __init__(self):
-        super(Sinefit, self).__init__("Sinefit")
-        self.description = "run sinefit alogrithm"
-        self.help = '''\
-          Compute zero crossings from voltage data data
-        '''
-        self.arg_description = ARGS_DESC
-
     def custom_args(self, parser):
-        parser.add_argument("config", help="JSON encoded dict")
+        parser.add_argument("--v-index", type="int",
+                            help="voltage element (1 indexed)")
+        parser.add_argument("--frequency", type="float", default=60.0,
+                            help="utility line frequency")
+        parser.add_argument("--min-freq", type="float", default=55.0,
+                            help="reject frequencies below threshold")
+        parser.add_argument("--max-freq", type="float", default=65.0,
+                            help="reject frequencies above threshold")
+        parser.add_argument("--min-amp", type="float", default=10.0,
+                            help="reject signals below threshold")
+        parser.description = ARGS_DESC
 
     async def run(self, parsed_args, inputs, outputs, nrows=0):
-        try:
-            self._parse_configs(json.loads(parsed_args.config))
-        except KeyError as e:
-            print("ERROR: invalid config string missing [%s]" % e)
-            exit(1)
+        # check configs
+        if(parsed_args.min_freq >= parsed_args.frequency):
+            raise helpers.FilterError("Error min_freq >= frequency")
+        if(parsed_args.max_freq <= parsed_args.frequency):
+            raise helpers.FilterError("Error max_freq <= frequency")
+        if(parsed_args.v_index <= 0):
+            raise helpers.FilterError("Error invalid v_index")
 
         try:
             iv = inputs['iv']
             zc = outputs['zero_crossings']
         except KeyError as e:
-            print("ERROR: required input [iv], output [zero_crossings]")
-            print("missing %s" % e)
-            exit(1)
+            raise helpers.FilterError("missing stream %s" % e)
     
         rows_processed = 0
-        f_expected = self.frequency
-        a_min = self.min_amp
-        f_min = self.min_freq
-        f_max = self.max_freq
-        column = self.v_index
+        f_expected = parsed_args.frequency
+        a_min = parsed_args.min_amp
+        f_min = parsed_args.min_freq
+        f_max = parsed_args.max_freq
+        # 1 indexed but ts is col 0 so this is correct
+        column = parsed_args.v_index
 
         while(True):
             data = await iv.read(flatten=True)
             await asyncio.sleep(0.1)
-            sys.stdout.flush()
             rows = data.shape[0]
 
             # Estimate sampling frequency from timestamps
@@ -111,8 +158,8 @@ class Sinefit(FilterModule):
 
                 # If amplitude is too low, results are probably just noise
                 if A < a_min:
-                    warn.warn("amplitude %s below minimum threshold %s\n" %
-                              (str(A), str(a_min)), t_min)
+                    warn.warn("amplitude %0.2f below minimum threshold %0.2f\n" %
+                              (A, a_min))
                     start += N
                     continue
 
@@ -162,36 +209,16 @@ class Sinefit(FilterModule):
 
             # Return the number of rows we've processed
             warn.reset(last_inserted_timestamp)
-            if last_inserted_timestamp:
-                now = timestamp_to_human(seconds_to_timestamp(
-                    last_inserted_timestamp)) + ": "
-            else:
-                now = ""
-            # logging.info("%d zc in %d/%d rows" %
-            #             (num_zc, start, len(data)))
             iv.consume(start)
             rows_processed += start
             if(nrows > 0 and rows_processed >= nrows):
                 break
 
-    def _parse_configs(self, config):
-        self.v_index = config['v_index']
-        self.min_amp = config['min_amp']
-        self.min_freq = config['min_freq']
-        self.max_freq = config['max_freq']
-        self.frequency = config['frequency']
-        if(self.min_freq >= self.frequency):
-            print("Error min_freq >= frequency")
-        if(self.max_freq <= self.frequency):
-            print("Error max_freq <= frequency")
-        if(self.v_index < 0):
-            print("Error invalid v_index")
-
-
 
 def main():
     filter = Sinefit()
     filter.start()
 
+    
 if __name__ == "__main__":
     main()
